API docs for “spamfighter.utils.terminal”

# Module s.u.terminal

Part of spamfighter.utils View Source

Terminal controller module.

Example of usage: print BG_BLUE + 'Text on blue background' + NORMAL print BLUE + UNDERLINE + 'Blue underlined text' + NORMAL print BLUE + BG_YELLOW + BOLD + 'text' + NORMAL

Function | default | Set the default attribute values
Function | setup | Set the terminal control strings
Function | render | Helper function to apply controls easily.

def default(): (source)
Set the default attribute values

def setup(): (source)
Set the terminal control strings

def render(text): (source)
Helper function to apply controls easily. Example: apply("%(GREEN)s%(BOLD)stext%(NORMAL)s") -> a bold green text